package yangtz.cs.liu.campus.service.curricula;

import com.baomidou.mybatisplus.extension.service.IService;
import yangtz.cs.liu.campus.domain.curricula.CurriculaStudent;
import yangtz.cs.liu.campus.vo.curricula.CurriculaStudentVo;

import java.util.List;

public interface ICurriculaStudentService extends IService<CurriculaStudent> {

    /**
     * 查看选课情况列表
     * @param curriculaStudentVo
     * @return
     */
    List<CurriculaStudentVo> selectCurriculaStudentList(CurriculaStudentVo curriculaStudentVo);

    /**
     * 查看春季选课情况列表
     * @param curriculaStudentVo
     * @return
     */
    List<CurriculaStudentVo> selectCurriculaStudentListCj(CurriculaStudentVo curriculaStudentVo);

    /**
     * 查看夏季选课情况列表
     * @param curriculaStudentVo
     * @return
     */
    List<CurriculaStudentVo> selectCurriculaStudentListXj(CurriculaStudentVo curriculaStudentVo);

    /**
     * 查看艺体选课情况列表
     * @param curriculaStudentVo
     * @return
     */
    List<CurriculaStudentVo> selectCurriculaStudentListYt(CurriculaStudentVo curriculaStudentVo);

    /**
     * 查看夏季选课情况列表
     * @param curriculaStudentVo
     * @return
     */
    List<CurriculaStudentVo> selectCurriculaStudentListXjQm(CurriculaStudentVo curriculaStudentVo);

    /**
     * 查看选课情况列表(班主任)
     * @param curriculaStudentVo
     * @return
     */
    List<CurriculaStudentVo> selectCurriculaStudentListBzr(CurriculaStudentVo curriculaStudentVo);

}
